Crate fizzyx_sys

Crate fizzyx_sys 

Low-level FFI bindings to the Fizzy WebAssembly interpreter.

This crate exposes the raw, unsafe C API declared in fizzy/fizzy.h, generated with bindgen. For a safe, ergonomic Rust API prefer the fizzyx crate, which is built on top of these bindings.

Structs

FizzyError
Error information.
FizzyExecutionContext
FizzyExecutionResult
Result of execution of a function.
FizzyExportDescription
Export description.
FizzyExternalFunction
External function.
FizzyExternalGlobal
External global.
FizzyExternalMemory
External memory.
FizzyExternalTable
External table.
FizzyFunctionType
Function type.
FizzyGlobalType
Global type.
FizzyImportDescription
Import description.
FizzyImportedFunction
Imported function.
FizzyImportedGlobal
Imported global.
FizzyInstance
FizzyLimits
Limits.
FizzyMemory
FizzyModule
FizzyTable

Constants

FizzyErrorInstantiationFailed
Instantiation failed.
FizzyErrorInvalidModule
Invalid module.
FizzyErrorMalformedModule
Malformed module.
FizzyErrorMemoryAllocationFailed
Memory allocation failed.
FizzyErrorOther
Other error.
FizzyExternalKindFunction
FizzyExternalKindGlobal
FizzyExternalKindMemory
FizzyExternalKindTable
FizzyMemoryPagesLimitDefault
Default hard limit of the memory size (256MB) to call fizzy_instantiate() and fizzy_resolve_instantiate().
FizzySuccess
Success.
FizzyValueTypeF32
FizzyValueTypeF64
FizzyValueTypeI32
FizzyValueTypeI64
FizzyValueTypeVoid
Special value, can be used only as function output type.

Functions

fizzy_clone_module
Make a copy of a module.
fizzy_create_execution_context
fizzy_create_metered_execution_context
fizzy_execute
Execute module function.
fizzy_find_exported_function
Find exported function by name.
fizzy_find_exported_function_index
Find index of exported function by name.
fizzy_find_exported_global
Find exported global by name.
fizzy_find_exported_memory
Find exported memory by name.
fizzy_find_exported_table
Find exported table by name.
fizzy_free_execution_context
fizzy_free_exported_function
Free resources associated with exported function.
fizzy_free_instance
Free resources associated with the instance.
fizzy_free_module
Free resources associated with the module.
fizzy_get_execution_context_depth
fizzy_get_execution_context_ticks
fizzy_get_export_count
Get number of exports defined in the module.
fizzy_get_export_description
Get the export description defined in the module.
fizzy_get_function_type
Get type of the function defined in the module.
fizzy_get_global_count
Get number of globals defined in the module.
fizzy_get_global_type
Get type of a given global defined in the module.
fizzy_get_import_count
Get number of imports defined in the module.
fizzy_get_import_description
Get the import description defined in the module.
fizzy_get_instance_memory_data
Get pointer to memory of an instance.
fizzy_get_instance_memory_size
Get size of memory of an instance.
fizzy_get_instance_module
Get pointer to module of an instance.
fizzy_get_type
Get type defined in the module.
fizzy_get_type_count
Get number of types defined in the module.
fizzy_instantiate
Instantiate a module.
fizzy_module_has_memory
Check whether module has a memory.
fizzy_module_has_start_function
Check whether module has a start function.
fizzy_module_has_table
Check whether module has a table.
fizzy_parse
Parse binary module.
fizzy_resolve_instantiate
Instantiate a module resolving imported functions.
fizzy_validate
Validate binary module.

Type Aliases

FizzyErrorCode
Error codes.
FizzyExternalFn
Pointer to external function.
FizzyExternalKind
External kind.
FizzyValueType
Value type.
_bindgen_ty_1

Unions

FizzyImportDescription__bindgen_ty_1
Import type definition.
FizzyValue
The data type representing numeric values.