pub unsafe extern "C" fn fizzy_execute(
instance: *mut FizzyInstance,
func_idx: u32,
args: *const FizzyValue,
ctx: *mut FizzyExecutionContext,
) -> FizzyExecutionResultExpand description
Execute module function.
@param instance Pointer to module instance. Cannot be NULL. @param args Pointer to the argument array. Can be NULL if function has 0 inputs. @param ctx Opaque pointer to execution context. If NULL new execution context will be allocated. @return Result of execution.
@note No validation is done on the number of arguments passed in @p args, nor on their types. When number of passed arguments or their types are different from the ones defined by the function type, behaviour is undefined.