fizzy_find_exported_function

Function fizzy_find_exported_function 

pub unsafe extern "C" fn fizzy_find_exported_function(
    instance: *mut FizzyInstance,
    name: *const c_char,
    out_function: *mut FizzyExternalFunction,
) -> bool
Find exported function by name.

@param instance Pointer to instance. Cannot be NULL. @param name The function name. NULL-terminated string. Cannot be NULL. @param out_function Pointer to output struct to store the found function. Cannot be NULL. If function is found, associated context is allocated, which must exist as long as the function can be called by some other instance, and should be destroyed with fizzy_free_exported_function() afterwards. When function is not found (false returned), this @p out_function is not modified, and fizzy_free_exported_function() must not be called. @return true if function was found, false otherwise.