fizzy_get_function_type

Function fizzy_get_function_type 

pub unsafe extern "C" fn fizzy_get_function_type(
    module: *const FizzyModule,
    func_idx: u32,
) -> FizzyFunctionType
Get type of the function defined in the module.

@param module Pointer to module. Cannot be NULL. @param func_idx Function index. Can be either index of an imported function or of a function defined in module. Behaviour is undefined if index is not valid according to module definition. @return Type of the function corresponding to the index.

@note All module function indices are greater than all imported function indices.