pub unsafe extern "C" fn fizzy_get_instance_memory_data(
instance: *mut FizzyInstance,
) -> *mut u8Expand description
Get pointer to memory of an instance.
@param instance Pointer to instance. Cannot be NULL. @return Pointer to memory data or NULL in case instance doesn’t have any memory.
@note Function returns pointer to memory regardless of whether memory is exported or not. @note For instances of the modules defined with memory of size 0 the returned pointer is not NULL.