fizzy_parse

Function fizzy_parse 

pub unsafe extern "C" fn fizzy_parse(
    wasm_binary: *const u8,
    wasm_binary_size: usize,
    error: *mut FizzyError,
) -> *const FizzyModule
Parse binary module.

@param wasm_binary Pointer to module binary data. @param wasm_binary_size Size of the module binary data. @param error Pointer to store detailed error information at. Can be NULL if error information is not required. @return non-NULL pointer to module in case of success, NULL otherwise.

@note FizzyError::code will be ::FizzySuccess if function returns non-NULL will and will not be ::FizzySuccess otherwise.