fizzy_validate

Function fizzy_validate 

pub unsafe extern "C" fn fizzy_validate(
    wasm_binary: *const u8,
    wasm_binary_size: usize,
    error: *mut FizzyError,
) -> bool
Validate binary module.

@param wasm_binary Pointer to module binary data. @param wasm_binary_size Size of the module binary data. @param error Pointer to store detailed error information at. Can be NULL if error information is not required. @return true if module is valid, false otherwise.

@note FizzyError::code will be ::FizzySuccess if function returns true and will not be ::FizzySuccess otherwise.