Structs
- Fizzy
Error - Error information.
- Fizzy
Execution Context - Fizzy
Execution Result - Result of execution of a function.
- Fizzy
Export Description - Export description.
- Fizzy
External Function - External function.
- Fizzy
External Global - External global.
- Fizzy
External Memory - External memory.
- Fizzy
External Table - External table.
- Fizzy
Function Type - Function type.
- Fizzy
Global Type - Global type.
- Fizzy
Import Description - Import description.
- Fizzy
Imported Function - Imported function.
- Fizzy
Imported Global - Imported global.
- Fizzy
Instance - Fizzy
Limits - Limits.
- Fizzy
Memory - Fizzy
Module - Fizzy
Table
Constants
- Fizzy
Error Instantiation Failed - Instantiation failed.
- Fizzy
Error Invalid Module - Invalid module.
- Fizzy
Error Malformed Module - Malformed module.
- Fizzy
Error Memory Allocation Failed - Memory allocation failed.
- Fizzy
Error Other - Other error.
- Fizzy
External Kind Function - Fizzy
External Kind Global - Fizzy
External Kind Memory - Fizzy
External Kind Table - Fizzy
Memory Pages Limit Default - Default hard limit of the memory size (256MB) to call fizzy_instantiate() and fizzy_resolve_instantiate().
- Fizzy
Success - Success.
- Fizzy
Value Type F32 - Fizzy
Value Type F64 - Fizzy
Value Type I32 - Fizzy
Value Type I64 - Fizzy
Value Type Void - Special value, can be used only as function output type.
Functions
- fizzy_
clone_ ⚠module - Make a copy of a module.
- fizzy_
create_ ⚠execution_ context - fizzy_
create_ ⚠metered_ execution_ context - fizzy_
execute ⚠ - Execute module function.
- fizzy_
find_ ⚠exported_ function - Find exported function by name.
- fizzy_
find_ ⚠exported_ function_ index - Find index of exported function by name.
- fizzy_
find_ ⚠exported_ global - Find exported global by name.
- fizzy_
find_ ⚠exported_ memory - Find exported memory by name.
- fizzy_
find_ ⚠exported_ table - Find exported table by name.
- fizzy_
free_ ⚠execution_ context - fizzy_
free_ ⚠exported_ function - Free resources associated with exported function.
- fizzy_
free_ ⚠instance - Free resources associated with the instance.
- fizzy_
free_ ⚠module - Free resources associated with the module.
- fizzy_
get_ ⚠execution_ context_ depth - fizzy_
get_ ⚠execution_ context_ ticks - fizzy_
get_ ⚠export_ count - Get number of exports defined in the module.
- fizzy_
get_ ⚠export_ description - Get the export description defined in the module.
- fizzy_
get_ ⚠function_ type - Get type of the function defined in the module.
- fizzy_
get_ ⚠global_ count - Get number of globals defined in the module.
- fizzy_
get_ ⚠global_ type - Get type of a given global defined in the module.
- fizzy_
get_ ⚠import_ count - Get number of imports defined in the module.
- fizzy_
get_ ⚠import_ description - Get the import description defined in the module.
- fizzy_
get_ ⚠instance_ memory_ data - Get pointer to memory of an instance.
- fizzy_
get_ ⚠instance_ memory_ size - Get size of memory of an instance.
- fizzy_
get_ ⚠instance_ module - Get pointer to module of an instance.
- fizzy_
get_ ⚠type - Get type defined in the module.
- fizzy_
get_ ⚠type_ count - Get number of types defined in the module.
- fizzy_
instantiate ⚠ - Instantiate a module.
- fizzy_
module_ ⚠has_ memory - Check whether module has a memory.
- fizzy_
module_ ⚠has_ start_ function - Check whether module has a start function.
- fizzy_
module_ ⚠has_ table - Check whether module has a table.
- fizzy_
parse ⚠ - Parse binary module.
- fizzy_
resolve_ ⚠instantiate - Instantiate a module resolving imported functions.
- fizzy_
validate ⚠ - Validate binary module.
Type Aliases
- Fizzy
Error Code - Error codes.
- Fizzy
External Fn - Pointer to external function.
- Fizzy
External Kind - External kind.
- Fizzy
Value Type - Value type.
- _bindgen_
ty_ 1
Unions
- Fizzy
Import Description__ bindgen_ ty_ 1 - Import type definition.
- Fizzy
Value - The data type representing numeric values.