pub unsafe extern "C" fn fizzy_get_export_description(
module: *const FizzyModule,
export_idx: u32,
) -> FizzyExportDescriptionExpand description
Get the export description defined in the module.
@param module Pointer to module. Cannot be NULL. @param export_idx Export index. Behaviour is undefined if index is not valid according to module definition. @return Description of the export corresponding to the index. FizzyExportDescription::name field points to the string stored inside the module and is valid as long as module is alive (including after successful instantiation.)